@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 import ConfigParser
 
+
 class Config:
     """Site configuration access."""
 
@@ -19,4 +20,7 @@ class Config:
             else:
                 return False
         else:
-            return val
\ No newline at end of file
+            return val
+
+    def items(self, section):
+        return self.config.items(section)
