@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
-from logya import Logya
+from __init__ import Logya
+
 
 class Test(Logya):
     """Test new features."""
@@ -12,4 +13,4 @@ class Test(Logya):
         from ext import ExtensionLoader
         el = ExtensionLoader()
         print el.get_by_type('doc')
-        print el.get_by_type('index')
\ No newline at end of file
+        print el.get_by_type('index')
