@@ -5,18 +5,26 @@ import tempfile
 import subprocess
 import unittest
 
+
 class TestCommand(unittest.TestCase):
+    """Test logya commands."""
 
     def _create(self):
+        """Call create command."""
+
         os.chdir(self.dir_root)
         subprocess.call(['logya', 'create', self.name])
 
     def setUp(self):
+        """Set up tasks."""
+
         self.name = 'logyatest'
         self.dir_root = tempfile.mkdtemp()
         self.dir_site = os.path.join(self.dir_root, self.name)
 
     def tearDown(self):
+        """Remove created files."""
+
         shutil.rmtree(self.dir_root, True)
 
     def test_create(self):
